==================
icemac.addressbook
==================

``icemac.addressbook`` is a multi user address book application accessible
through the web: Store, edit, search and export addresses, phone numbers, …
using a web browser.

.. toctree::
   :maxdepth: 2

   features
   screenshots
   download
   installation
   runthetests
   runtheapplication
   usermanagement

Documentation in other languages:

* `Deutsprachige Dokumentation`_ (https://offb213.de)

===========
Development
===========

.. toctree::
   :maxdepth: 1

   changelog
   todo
   hacking

Image credits: `Martin Šnajdr`_


.. _`Deutsprachige Dokumentation` : https://offb213.de
.. _`Martin Šnajdr` : https://design.tutsplus.com/tutorials/create-a-custom-mac-osx-style-ring-binder-address-book-icon--psd-313

